@@ -1,13 +1,9 @@
 """All the engines that use a GET endpoint."""
-from urllib.parse import urljoin
-
-from typing import List
 
 from requests import PreparedRequest
 
 from datalake_scripts.common.base_engine import BaseEngine
 from datalake_scripts.common.logger import logger
-from datalake_scripts.helper_scripts.output_builder import CsvBuilder
 
 
 class GetEngine(BaseEngine):
@@ -33,6 +29,9 @@ class ThreatsSearch(GetEngine):
     Threats Search Engine
     """
 
+    def _build_url(self, endpoint_config: dict, environment: str):
+        return self._build_url_for_endpoint('threats')
+
     def get_json(self, list_threats: list):
         """
         Retrieve the JSON file of a list of threats and their comments.
@@ -61,26 +60,12 @@ class ThreatsSearch(GetEngine):
         return dict_threat, list_of_lost_hashes
 
 
-class BulkSearch(GetEngine):
-    """
-    Bulk search engines
-    """
-
-    def get_threats(self, query_hash: str, query_fields: List[str] = None) -> dict:
-        params = {}
-        if query_fields:
-            params['query_fields'] = ','.join(query_fields)
-        url_without_param = urljoin(self.url, query_hash)
-        req = PreparedRequest()  # Adding parameters using requests' tool
-        req.prepare_url(url_without_param, params)
-
-        response = self.datalake_requests(req.url, 'get', headers={'Authorization': self.tokens[0]})
-        return response
-
-
 class LookupThreats(GetEngine):
     """Lookup threats engine"""
 
+    def _build_url(self, endpoint_config: dict, environment: str):
+        return self._build_url_for_endpoint('lookup')
+
     def get_lookup_result(self, threat, atom_type, hashkey_only) -> list:
         params = {'atom_value': threat, 'atom_type': atom_type, 'hashkey_only': hashkey_only}
         req = PreparedRequest()  # Adding parameters using requests' tool
@@ -89,7 +74,7 @@ class LookupThreats(GetEngine):
                                           headers={'Authorization': self.tokens[0]})
         return response
 
-    def lookup_threats(self, threats: list, atom_type, hashkey_only, output_type):
+    def lookup_threats(self, threats: list, atom_type, hashkey_only):
         boolean_to_text_and_color = {True: ('FOUND', '\x1b[6;30;42m'),
                                      False: ('NOT_FOUND', '\x1b[6;30;41m')}
         complete_response = None
@@ -102,6 +87,22 @@ class LookupThreats(GetEngine):
             logger.info('{}{} hashkey:{} {}\x1b[0m'.format(color, threat, response['hashkey'], text))
             complete_response = {} if not complete_response else complete_response
             complete_response[threat] = response
-        if output_type == 'text/csv':
-            return CsvBuilder.create_csv(complete_response, atom_type)
         return complete_response
+
+
+class Threats(GetEngine):
+    """Retrieve threats based on an query hash using the Advanced Search endpoint
+    The endpoint limit the number of result to 5 000 threats but allow more output than the bulk search
+    """
+
+    def _build_url(self, endpoint_config: dict, environment: str):
+        return self._build_url_for_endpoint('advanced-search')
+
+    def get_threats(self, query_hash: str, limit=10, response_format="application/json") -> dict:
+        url = self.url + query_hash
+        params = {'limit': limit}
+        req = PreparedRequest()  # Adding parameters using requests' tool
+        req.prepare_url(url, params)
+        headers = {'Authorization': self.tokens[0], 'Accept': response_format}
+        response = self.datalake_requests(req.url, 'get', headers=headers)
+        return response
